summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorGlenn Kasten <gkasten@google.com>2012-11-02 10:51:32 -0700
committerAndroid (Google) Code Review <android-gerrit@google.com>2012-11-02 10:51:33 -0700
commit821cea93f38065592456d6644600f5ee1123fe72 (patch)
tree7dfad9c87fc42fcb090d74ae09a5408be16e2fd5 /include
parentefced1d83add1d0f1210ac4d949cce8dd345b672 (diff)
parentb64497eb8724c4c372fffdbf3ee30543432953c5 (diff)
downloadframeworks_av-821cea93f38065592456d6644600f5ee1123fe72.zip
frameworks_av-821cea93f38065592456d6644600f5ee1123fe72.tar.gz
frameworks_av-821cea93f38065592456d6644600f5ee1123fe72.tar.bz2
Merge "Add NBAIO support for more sample rates"
Diffstat (limited to 'include')
-rw-r--r--include/media/nbaio/NBAIO.h14
1 files changed, 6 insertions, 8 deletions
diff --git a/include/media/nbaio/NBAIO.h b/include/media/nbaio/NBAIO.h
index 81f42ed..f5d6eb5 100644
--- a/include/media/nbaio/NBAIO.h
+++ b/include/media/nbaio/NBAIO.h
@@ -45,17 +45,15 @@ enum {
// Negotiation of format is based on the data provider and data sink, or the data consumer and
// data source, exchanging prioritized arrays of offers and counter-offers until a single offer is
// mutually agreed upon. Each offer is an NBAIO_Format. For simplicity and performance,
// NBAIO_Format is an enum that ties together the most important combinations of the various
// attributes, rather than a struct with separate fields for format, sample rate, channel count,
// interleave, packing, alignment, etc. The reason is that NBAIO_Format tries to abstract out only
-// the combinations that are actually needed within AudioFligner. If the list of combinations grows
+// the combinations that are actually needed within AudioFlinger. If the list of combinations grows
// too large, then this decision should be re-visited.
-enum NBAIO_Format {
- Format_Invalid,
- Format_SR44_1_C2_I16, // 44.1 kHz PCM stereo interleaved 16-bit signed
- Format_SR48_C2_I16, // 48 kHz PCM stereo interleaved 16-bit signed
- Format_SR44_1_C1_I16, // 44.1 kHz PCM mono interleaved 16-bit signed
- Format_SR48_C1_I16, // 48 kHz PCM mono interleaved 16-bit signed
+// Sample rate and channel count are explicit, PCM interleaved 16-bit is assumed.
+typedef unsigned NBAIO_Format;
+enum {
+ Format_Invalid
};
// Return the frame size of an NBAIO_Format in bytes
@@ -45,17 +45,15 @@ enum {
// data source, exchanging prioritized arrays of offers and counter-offers until a single offer is
// mutually agreed upon. Each offer is an NBAIO_Format. For simplicity and performance,
-// NBAIO_Format is an enum that ties together the most important combinations of the various
+// NBAIO_Format is a typedef that ties together the most important combinations of the various
// attributes, rather than a struct with separate fields for format, sample rate, channel count,
// interleave, packing, alignment, etc. The reason is that NBAIO_Format tries to abstract out only